@@ -1,17 +1,23 @@
 """Tests for the credit module managing transactions/subtransactions."""
 from datetime import date
-from unittest.mock import patch, Mock
+from unittest.mock import Mock, patch
 
 import pytest
-from werkzeug.exceptions import NotFound
 from sqlalchemy.exc import IntegrityError
+from werkzeug.exceptions import NotFound
 
-from monopyly.database.models import (
-    CreditTransaction, CreditTransactionView, CreditSubtransaction, CreditTag
-)
 from monopyly.credit.transactions import (
-    CreditTransactionHandler, CreditTagHandler, save_transaction
+    CreditTagHandler,
+    CreditTransactionHandler,
+    save_transaction,
 )
+from monopyly.database.models import (
+    CreditSubtransaction,
+    CreditTag,
+    CreditTransaction,
+    CreditTransactionView,
+)
+
 from ..helpers import TestHandler
 
 
@@ -24,10 +30,16 @@ def _mock_subtransaction_mappings():
     # Use a function to regenerate mappings (avoid persisting mutations)
     mock_tags = [Mock(name=f"Mock tag {_+1}") for _ in range(3)]
     mappings = [
-        {"subtotal": 100.00, "note": "Mock subtransaction mapping 1",
-         "tags": mock_tags[:2]},
-        {"subtotal": 200.00, "note": "Mock subtransaction mapping 2",
-         "tags": mock_tags[:1]},
+        {
+            "subtotal": 100.00,
+            "note": "Mock subtransaction mapping 1",
+            "tags": mock_tags[:2],
+        },
+        {
+            "subtotal": 200.00,
+            "note": "Mock subtransaction mapping 2",
+            "tags": mock_tags[:1],
+        },
     ]
     return mappings
 
@@ -48,70 +60,118 @@ def mock_tags():
 
 
 class TestCreditTransactionHandler(TestHandler):
-
     # References only include entries accessible to the authorized login
     #   - ordered by date (most recent first)
     db_reference = [
-        CreditTransactionView(id=12, internal_transaction_id=None,
-                              statement_id=7,
-                              transaction_date=date(2020, 6, 5),
-                              vendor="Boardwalk", total=12.34,
-                              notes="Back for more..."),
-        CreditTransactionView(id=11, internal_transaction_id=None,
-                              statement_id=7,
-                              transaction_date=date(2020, 6, 5),
-                              vendor="Reading Railroad", total=253.99,
-                              notes="Conducting business"),
-        CreditTransactionView(id=8, internal_transaction_id=None,
-                              statement_id=5,
-                              transaction_date=date(2020, 5, 30),
-                              vendor="Water Works", total=26.87,
-                              notes="Tough loss"),
-        CreditTransactionView(id=10, internal_transaction_id=None,
-                              statement_id=6,
-                              transaction_date=date(2020, 5, 10),
-                              vendor="Income Tax Board", total=-1230.00,
-                              notes="Refund"),
-        CreditTransactionView(id=7, internal_transaction_id=2,
-                              statement_id=4,
-                              transaction_date=date(2020, 5, 4),
-                              vendor="JP Morgan Chance", total=-109.21,
-                              notes="Credit card payment"),
-        CreditTransactionView(id=6, internal_transaction_id=None,
-                              statement_id=4,
-                              transaction_date=date(2020, 5, 1),
-                              vendor="Marvin Gardens", total=6500.00,
-                              notes="Expensive real estate"),
-        CreditTransactionView(id=5, internal_transaction_id=None,
-                              statement_id=4,
-                              transaction_date=date(2020, 4, 25),
-                              vendor="Electric Company", total=99.00,
-                              notes="Electric bill"),
-        CreditTransactionView(id=9, internal_transaction_id=None,
-                              statement_id=6,
-                              transaction_date=date(2020, 4, 20),
-                              vendor="Pennsylvania Avenue", total=1600.00,
-                              notes="Big house tour"),
-        CreditTransactionView(id=2, internal_transaction_id=None,
-                              statement_id=2,
-                              transaction_date=date(2020, 4, 13),
-                              vendor="Top Left Corner", total=1.00,
-                              notes="Parking (thought it was free)"),
-        CreditTransactionView(id=4, internal_transaction_id=None,
-                              statement_id=3,
-                              transaction_date=date(2020, 4, 5),
-                              vendor="Park Place", total=65.00,
-                              notes="One for the park; One for the place"),
-        CreditTransactionView(id=3, internal_transaction_id=None,
-                              statement_id=3,
-                              transaction_date=date(2020, 3, 20),
-                              vendor="Boardwalk", total=43.21,
-                              notes="Merry-go-round"),
-        CreditTransactionView(id=13, internal_transaction_id=None,
-                              statement_id=2,
-                              transaction_date=date(2020, 3, 10),
-                              vendor="Community Chest", total=None,
-                              notes=None),  # transaction without subtransactions
+        CreditTransactionView(
+            id=12,
+            internal_transaction_id=None,
+            statement_id=7,
+            transaction_date=date(2020, 6, 5),
+            vendor="Boardwalk",
+            total=12.34,
+            notes="Back for more...",
+        ),
+        CreditTransactionView(
+            id=11,
+            internal_transaction_id=None,
+            statement_id=7,
+            transaction_date=date(2020, 6, 5),
+            vendor="Reading Railroad",
+            total=253.99,
+            notes="Conducting business",
+        ),
+        CreditTransactionView(
+            id=8,
+            internal_transaction_id=None,
+            statement_id=5,
+            transaction_date=date(2020, 5, 30),
+            vendor="Water Works",
+            total=26.87,
+            notes="Tough loss",
+        ),
+        CreditTransactionView(
+            id=10,
+            internal_transaction_id=None,
+            statement_id=6,
+            transaction_date=date(2020, 5, 10),
+            vendor="Income Tax Board",
+            total=-1230.00,
+            notes="Refund",
+        ),
+        CreditTransactionView(
+            id=7,
+            internal_transaction_id=2,
+            statement_id=4,
+            transaction_date=date(2020, 5, 4),
+            vendor="JP Morgan Chance",
+            total=-109.21,
+            notes="Credit card payment",
+        ),
+        CreditTransactionView(
+            id=6,
+            internal_transaction_id=None,
+            statement_id=4,
+            transaction_date=date(2020, 5, 1),
+            vendor="Marvin Gardens",
+            total=6500.00,
+            notes="Expensive real estate",
+        ),
+        CreditTransactionView(
+            id=5,
+            internal_transaction_id=None,
+            statement_id=4,
+            transaction_date=date(2020, 4, 25),
+            vendor="Electric Company",
+            total=99.00,
+            notes="Electric bill",
+        ),
+        CreditTransactionView(
+            id=9,
+            internal_transaction_id=None,
+            statement_id=6,
+            transaction_date=date(2020, 4, 20),
+            vendor="Pennsylvania Avenue",
+            total=1600.00,
+            notes="Big house tour",
+        ),
+        CreditTransactionView(
+            id=2,
+            internal_transaction_id=None,
+            statement_id=2,
+            transaction_date=date(2020, 4, 13),
+            vendor="Top Left Corner",
+            total=1.00,
+            notes="Parking (thought it was free)",
+        ),
+        CreditTransactionView(
+            id=4,
+            internal_transaction_id=None,
+            statement_id=3,
+            transaction_date=date(2020, 4, 5),
+            vendor="Park Place",
+            total=65.00,
+            notes="One for the park; One for the place",
+        ),
+        CreditTransactionView(
+            id=3,
+            internal_transaction_id=None,
+            statement_id=3,
+            transaction_date=date(2020, 3, 20),
+            vendor="Boardwalk",
+            total=43.21,
+            notes="Merry-go-round",
+        ),
+        # Transaction without subtransactions
+        CreditTransactionView(
+            id=13,
+            internal_transaction_id=None,
+            statement_id=2,
+            transaction_date=date(2020, 3, 10),
+            vendor="Community Chest",
+            total=None,
+            notes=None,
+        ),
     ]
 
     def test_initialization(self, transaction_handler):
@@ -128,61 +188,92 @@ class TestCreditTransactionHandler(TestHandler):
 
     @pytest.mark.parametrize(
         "statement_ids, card_ids, active, sort_order, reference_entries",
-        [[None, None, None, "DESC",             # defaults
-          db_reference],
-         [(3, ), None, None, "DESC",
-          [row for row in db_reference if row.statement_id == 3]],
-         [None, (2, 3), None, "DESC",
-          [row for row in db_reference if row.statement_id in (2, 3, 4, 5)]],
-         [None, None, True, "DESC",             # card 2 (statement 2) inactive
-          [row for row in db_reference if row.statement_id != 2]],
-         [None, None, False, "DESC",
-          [row for row in db_reference if row.statement_id == 2]],
-         [None, None, None, "ASC",
-          db_reference[::-1]]]
+        [
+            [None, None, None, "DESC", db_reference],  # defaults
+            [
+                (3,),
+                None,
+                None,
+                "DESC",
+                (row for row in db_reference if row.statement_id == 3),
+            ],
+            [
+                None,
+                (2, 3),
+                None,
+                "DESC",
+                (row for row in db_reference if row.statement_id in (2, 3, 4, 5)),
+            ],
+            [  # card 2 (statement 2) inactive
+                None,
+                None,
+                True,
+                "DESC",
+                (row for row in db_reference if row.statement_id != 2),
+            ],
+            [
+                None,
+                None,
+                False,
+                "DESC",
+                (row for row in db_reference if row.statement_id == 2),
+            ],
+            [None, None, None, "ASC", db_reference[::-1]],
+        ],
     )
-    def test_get_transactions(self, transaction_handler, statement_ids,
-                              card_ids, active, sort_order, reference_entries):
+    def test_get_transactions(
+        self,
+        transaction_handler,
+        statement_ids,
+        card_ids,
+        active,
+        sort_order,
+        reference_entries,
+    ):
         transactions = transaction_handler.get_transactions(
             statement_ids, card_ids, active, sort_order
         )
-        self.assertEntriesMatch(
-            transactions, reference_entries, order=True
-        )
+        self.assertEntriesMatch(transactions, reference_entries, order=True)
 
     @pytest.mark.parametrize(
-        "transaction_id, reference_entry",
-        [[2, db_reference[8]],
-         [3, db_reference[10]]]
+        "transaction_id, reference_entry", [[2, db_reference[8]], [3, db_reference[10]]]
     )
-    def test_get_entry(self, transaction_handler, transaction_id,
-                       reference_entry):
+    def test_get_entry(self, transaction_handler, transaction_id, reference_entry):
         transaction = transaction_handler.get_entry(transaction_id)
         self.assertEntryMatches(transaction, reference_entry)
 
     @pytest.mark.parametrize(
         "transaction_id, exception",
-        [[1, NotFound],   # Not the logged in user
-         [14, NotFound]]  # Not in the database
+        [
+            [1, NotFound],  # -- the tag user is not the logged in user
+            [14, NotFound],  # - the tag is not in the database
+        ],
     )
-    def test_get_entry_invalid(self, transaction_handler, transaction_id,
-                               exception):
+    def test_get_entry_invalid(self, transaction_handler, transaction_id, exception):
         with pytest.raises(exception):
             transaction_handler.get_entry(transaction_id)
 
     @pytest.mark.parametrize(
         "mapping",
-        [{"internal_transaction_id": None, "statement_id": 4,
-          "transaction_date": date(2020, 5, 3), "vendor": "Baltic Avenue",
-          "subtransactions": _mock_subtransaction_mappings()},
-         {"internal_transaction_id": 2, "statement_id": 6,
-          "transaction_date": date(2020, 5, 3),
-          "vendor": "Mediterranean Avenue",
-          "subtransactions": _mock_subtransaction_mappings()}]
+        [
+            {
+                "internal_transaction_id": None,
+                "statement_id": 4,
+                "transaction_date": date(2020, 5, 3),
+                "vendor": "Baltic Avenue",
+                "subtransactions": _mock_subtransaction_mappings(),
+            },
+            {
+                "internal_transaction_id": 2,
+                "statement_id": 6,
+                "transaction_date": date(2020, 5, 3),
+                "vendor": "Mediterranean Avenue",
+                "subtransactions": _mock_subtransaction_mappings(),
+            },
+        ],
     )
     @patch("monopyly.credit.transactions.CreditTagHandler.get_tags")
-    def test_add_entry(self, mock_method, transaction_handler, mock_tags,
-                       mapping):
+    def test_add_entry(self, mock_method, transaction_handler, mock_tags, mapping):
         # Mock the tags found by the tag handler
         mock_method.return_value = mock_tags[:2]
         # Add the entry
@@ -196,29 +287,49 @@ class TestCreditTransactionHandler(TestHandler):
         self.assertNumberOfMatches(
             1,
             CreditTransaction.id,
-            CreditTransaction.transaction_date == date(2020, 5, 3)
+            CreditTransaction.transaction_date == date(2020, 5, 3),
         )
 
     @pytest.mark.parametrize(
         "mapping, exception",
-        [[{"internal_transaction_id": None, "invalid_field": "Test",
-           "transaction_date": date(2022, 5, 3), "vendor": "Baltic Avenue",
-           "subtransactions": _mock_subtransaction_mappings()},
-          TypeError],
-         [{"internal_transaction_id": 2, "statement_id": 4,
-           "transaction_date": date(2022, 5, 3),
-           "subtransactions": _mock_subtransaction_mappings()},
-          IntegrityError],
-         [{"internal_transaction_id": 2, "statement_id": 4,
-           "transaction_date": date(2022, 5, 3), "vendor": "Baltic Avenue"},
-          KeyError]]
+        [
+            [
+                {
+                    "internal_transaction_id": None,
+                    "invalid_field": "Test",
+                    "transaction_date": date(2022, 5, 3),
+                    "vendor": "Baltic Avenue",
+                    "subtransactions": _mock_subtransaction_mappings(),
+                },
+                TypeError,
+            ],
+            [
+                {
+                    "internal_transaction_id": 2,
+                    "statement_id": 4,
+                    "transaction_date": date(2022, 5, 3),
+                    "subtransactions": _mock_subtransaction_mappings(),
+                },
+                IntegrityError,
+            ],
+            [
+                {
+                    "internal_transaction_id": 2,
+                    "statement_id": 4,
+                    "transaction_date": date(2022, 5, 3),
+                    "vendor": "Baltic Avenue",
+                },
+                KeyError,
+            ],
+        ],
     )
     def test_add_entry_invalid(self, transaction_handler, mapping, exception):
         with pytest.raises(exception):
             transaction_handler.add_entry(**mapping)
 
-    def test_add_entry_invalid_user(self, transaction_handler,
-                                    mock_subtransaction_mappings):
+    def test_add_entry_invalid_user(
+        self, transaction_handler, mock_subtransaction_mappings
+    ):
         mapping = {
             "internal_transaction_id": 2,
             "statement_id": 1,
@@ -233,14 +344,18 @@ class TestCreditTransactionHandler(TestHandler):
 
     @pytest.mark.parametrize(
         "mapping",
-        [{"internal_transaction_id": None, "statement_id": 4,
-          "transaction_date": date(2022, 5, 3),
-          "subtransactions": _mock_subtransaction_mappings()},
-         {"transaction_date": date(2022, 5, 3)}]
+        [
+            {
+                "internal_transaction_id": None,
+                "statement_id": 4,
+                "transaction_date": date(2022, 5, 3),
+                "subtransactions": _mock_subtransaction_mappings(),
+            },
+            {"transaction_date": date(2022, 5, 3)},
+        ],
     )
     @patch("monopyly.credit.transactions.CreditTagHandler.get_tags")
-    def test_update_entry(self, mock_method, transaction_handler, mock_tags,
-                          mapping):
+    def test_update_entry(self, mock_method, transaction_handler, mock_tags, mapping):
         # Mock the tags found by the tag handler
         mock_method.return_value = mock_tags[:2]
         # Add the entry
@@ -259,20 +374,23 @@ class TestCreditTransactionHandler(TestHandler):
         self.assertNumberOfMatches(
             1,
             CreditTransaction.id,
-            CreditTransaction.transaction_date == date(2022, 5, 3)
+            CreditTransaction.transaction_date == date(2022, 5, 3),
         )
 
     @pytest.mark.parametrize(
         "transaction_id, mapping, exception",
-        [[1, {"statement_id": 1, "transaction_date": date(2022, 5, 3)},
-          NotFound],                                        # wrong user
-         [5, {"statement_id": 4, "invalid_field": "Test"},
-          ValueError],                                      # invalid field
-         [14, {"statement_id": 4, "transaction_date": date(2022, 5, 3)},
-          NotFound]]                                        # nonexistent ID
+        [
+            # Wrong transaction user
+            [1, {"statement_id": 1, "transaction_date": date(2022, 5, 3)}, NotFound],
+            # Invalid field
+            [5, {"statement_id": 4, "invalid_field": "Test"}, ValueError],
+            # Nonexistent ID
+            [14, {"statement_id": 4, "transaction_date": date(2022, 5, 3)}, NotFound],
+        ],
     )
-    def test_update_entry_invalid(self, transaction_handler, transaction_id,
-                                  mapping, exception):
+    def test_update_entry_invalid(
+        self, transaction_handler, transaction_id, mapping, exception
+    ):
         with pytest.raises(exception):
             transaction_handler.update_entry(transaction_id, **mapping)
 
@@ -288,11 +406,12 @@ class TestCreditTransactionHandler(TestHandler):
 
     @pytest.mark.parametrize(
         "entry_id, exception",
-        [[1, NotFound],    # should not be able to delete other user entries
-         [14, NotFound]]   # should not be able to delete nonexistent entries
+        [
+            [1, NotFound],  # -- should not be able to delete other user entries
+            [14, NotFound],  # - should not be able to delete nonexistent entries
+        ],
     )
-    def test_delete_entry_invalid(self, transaction_handler, entry_id,
-                                    exception):
+    def test_delete_entry_invalid(self, transaction_handler, entry_id, exception):
         with pytest.raises(exception):
             transaction_handler.delete_entry(entry_id)
 
@@ -303,7 +422,6 @@ def tag_handler(client_context):
 
 
 class TestCreditTagHandler(TestHandler):
-
     # References only include entries accessible to the authorized login
     db_reference = [
         CreditTag(id=2, user_id=3, parent_id=None, tag_name="Transportation"),
@@ -338,30 +456,31 @@ class TestCreditTagHandler(TestHandler):
 
     @pytest.mark.parametrize(
         "tag_names, transaction_ids, subtransaction_ids, ancestors, reference_entries",
-        [[None, None, None, None,             # defaults
-          db_reference],
-         [("Railroad", "Utilities"), None, None, None,
-          db_reference[2:4]],
-         [None, (10, 11, 12), None, None,
-          [db_reference[0], db_reference[2]]],
-         [None, None, (5, 6, 7), None,
-          db_reference[3:]],
-         [("Parking",), None, None, True,
-          db_reference[0:2]],
-         [("Parking", "Transportation"), None, None, False,
-          [db_reference[1]]]]
+        [
+            [None, None, None, None, db_reference],  # defaults
+            [("Railroad", "Utilities"), None, None, None, db_reference[2:4]],
+            [None, (10, 11, 12), None, None, [db_reference[0], db_reference[2]]],
+            [None, None, (5, 6, 7), None, db_reference[3:]],
+            [("Parking",), None, None, True, db_reference[0:2]],
+            [("Parking", "Transportation"), None, None, False, [db_reference[1]]],
+        ],
     )
-    def test_get_tags(self, tag_handler, tag_names, transaction_ids,
-                      subtransaction_ids, ancestors, reference_entries):
+    def test_get_tags(
+        self,
+        tag_handler,
+        tag_names,
+        transaction_ids,
+        subtransaction_ids,
+        ancestors,
+        reference_entries,
+    ):
         tags = tag_handler.get_tags(
             tag_names, transaction_ids, subtransaction_ids, ancestors
         )
         self.assertEntriesMatch(tags, reference_entries)
 
     @pytest.mark.parametrize(
-        "tag_id, reference_entry",
-        [[2, db_reference[0]],
-         [3, db_reference[1]]]
+        "tag_id, reference_entry", [[2, db_reference[0]], [3, db_reference[1]]]
     )
     def test_get_entry(self, tag_handler, tag_id, reference_entry):
         tag = tag_handler.get_entry(tag_id)
@@ -369,27 +488,27 @@ class TestCreditTagHandler(TestHandler):
 
     @pytest.mark.parametrize(
         "tag_id, exception",
-        [[1, NotFound],   # Not the logged in user
-         [7, NotFound]]   # Not in the database
+        [[1, NotFound], [7, NotFound]],  # Not the logged in user  # Not in the database
     )
     def test_get_entry_invalid(self, tag_handler, tag_id, exception):
         with pytest.raises(exception):
             tag_handler.get_entry(tag_id)
 
     @pytest.mark.parametrize(
-        'tag, expected_subtags',
-        [[db_reference[0], db_reference[1:3]],
-         [db_reference[3], db_reference[4:]]]
+        "tag, expected_subtags",
+        [[db_reference[0], db_reference[1:3]], [db_reference[3], db_reference[4:]]],
     )
     def test_get_subtags(self, tag_handler, tag, expected_subtags):
         subtags = tag_handler.get_subtags(tag)
         self.assertEntriesMatch(subtags, expected_subtags)
 
     @pytest.mark.parametrize(
-        'tag, expected_supertag',
-        [[db_reference[1], db_reference[0]],
-         [db_reference[2], db_reference[0]],
-         [db_reference[4], db_reference[3]]]
+        "tag, expected_supertag",
+        [
+            [db_reference[1], db_reference[0]],
+            [db_reference[2], db_reference[0]],
+            [db_reference[4], db_reference[3]],
+        ],
     )
     def test_get_supertag(self, tag_handler, tag, expected_supertag):
         supertag = tag_handler.get_supertag(tag)
@@ -397,8 +516,10 @@ class TestCreditTagHandler(TestHandler):
 
     @pytest.mark.parametrize(
         "root_tag, expected_hierarchy",
-        [[None, db_reference_hierarchy],
-         [db_reference[0], db_reference_hierarchy[db_reference[0]]]]
+        [
+            [None, db_reference_hierarchy],
+            [db_reference[0], db_reference_hierarchy[db_reference[0]]],
+        ],
     )
     def test_get_hierarchy(self, tag_handler, root_tag, expected_hierarchy):
         hierarchy = tag_handler.get_hierarchy(root_tag)
@@ -406,10 +527,12 @@ class TestCreditTagHandler(TestHandler):
 
     @pytest.mark.parametrize(
         "tag, expected_ancestors",
-        [[db_reference[1], [db_reference[0]]],
-         [db_reference[2], [db_reference[0]]],
-         [db_reference[0], []],
-         [db_reference[4], [db_reference[3]]]]
+        [
+            [db_reference[1], (db_reference[0],)],
+            [db_reference[2], (db_reference[0],)],
+            [db_reference[0], ()],
+            [db_reference[4], (db_reference[3],)],
+        ],
     )
     def test_get_ancestors(self, tag_handler, tag, expected_ancestors):
         ancestors = tag_handler.get_ancestors(tag)
@@ -417,24 +540,23 @@ class TestCreditTagHandler(TestHandler):
 
     @pytest.mark.parametrize(
         "tag_name, reference_entry",
-        [["Transportation", db_reference[0]],
-         ["Electricity", db_reference[4]]]
+        [["Transportation", db_reference[0]], ["Electricity", db_reference[4]]],
     )
     def test_find_tag(self, tag_handler, tag_name, reference_entry):
         tag = tag_handler.find_tag(tag_name)
         self.assertEntryMatches(tag, reference_entry)
 
-    @pytest.mark.parametrize(
-        "tag_name", ["Trains", None]
-    )
+    @pytest.mark.parametrize("tag_name", ["Trains", None])
     def test_find_tag_none_exist(self, tag_handler, tag_name):
         tag = tag_handler.find_tag(tag_name)
         assert tag is None
 
     @pytest.mark.parametrize(
         "mapping",
-        [{"user_id": 3, "parent_id": None, "tag_name": "Entertainment"},
-         {"user_id": 3, "parent_id": 5, "tag_name": "Water"}]
+        [
+            {"user_id": 3, "parent_id": None, "tag_name": "Entertainment"},
+            {"user_id": 3, "parent_id": 5, "tag_name": "Water"},
+        ],
     )
     def test_add_entry(self, tag_handler, mapping):
         # Add the entry
@@ -448,9 +570,13 @@ class TestCreditTagHandler(TestHandler):
 
     @pytest.mark.parametrize(
         "mapping, exception",
-        [[{"user_id": 3, "invalid_field": None, "tag_name": "Entertainment"},
-          TypeError],
-         [{"user_id": 3, "parent_id": 5}, IntegrityError]]
+        [
+            [
+                {"user_id": 3, "invalid_field": None, "tag_name": "Entertainment"},
+                TypeError,
+            ],
+            [{"user_id": 3, "parent_id": 5}, IntegrityError],
+        ],
     )
     def test_add_entry_invalid(self, tag_handler, mapping, exception):
         with pytest.raises(exception):
@@ -469,8 +595,10 @@ class TestCreditTagHandler(TestHandler):
 
     @pytest.mark.parametrize(
         "mapping",
-        [{"user_id": 3, "parent_id": None, "tag_name": "Trains"},
-         {"user_id": 3, "tag_name": "Trains"}]
+        [
+            {"user_id": 3, "parent_id": None, "tag_name": "Trains"},
+            {"user_id": 3, "tag_name": "Trains"},
+        ],
     )
     def test_update_entry(self, tag_handler, mapping):
         # Add the entry
@@ -478,29 +606,24 @@ class TestCreditTagHandler(TestHandler):
         # Check that the entry object was properly updated
         assert tag.tag_name == "Trains"
         # Check that the entry was updated in the database
-        self.assertNumberOfMatches(
-            1, CreditTag.id, CreditTag.tag_name == "Trains"
-        )
+        self.assertNumberOfMatches(1, CreditTag.id, CreditTag.tag_name == "Trains")
 
     @pytest.mark.parametrize(
         "tag_id, mapping, exception",
-        [[1, {"user_id": 3, "tag_name": "Test"},
-          NotFound],                                        # wrong user
-         [5, {"user_id": 3, "invalid_field": "Test"},
-          ValueError],                                      # invalid field
-         [7, {"user_id": 3, "tag_name": "Test"},
-          NotFound]]                                        # nonexistent ID
+        [
+            # Wrong tag user
+            [1, {"user_id": 3, "tag_name": "Test"}, NotFound],
+            # Invalid field
+            [5, {"user_id": 3, "invalid_field": "Test"}, ValueError],
+            # Nonexistent ID
+            [7, {"user_id": 3, "tag_name": "Test"}, NotFound],
+        ],
     )
-    def test_update_entry_invalid(self, tag_handler, tag_id, mapping,
-                                  exception):
+    def test_update_entry_invalid(self, tag_handler, tag_id, mapping, exception):
         with pytest.raises(exception):
             tag_handler.update_entry(tag_id, **mapping)
 
-    @pytest.mark.parametrize(
-        "entry_id, subtag_ids",
-        [[4, ()],
-         [5, (6,)]]
-    )
+    @pytest.mark.parametrize("entry_id, subtag_ids", [[4, ()], [5, (6,)]])
     def test_delete_entry(self, tag_handler, entry_id, subtag_ids):
         self.assert_entry_deletion_succeeds(tag_handler, entry_id)
         # Check that the cascading entries were deleted
@@ -512,8 +635,10 @@ class TestCreditTagHandler(TestHandler):
 
     @pytest.mark.parametrize(
         "entry_id, exception",
-        [[1, NotFound],    # should not be able to delete other user entries
-         [7, NotFound]]    # should not be able to delete nonexistent entries
+        [
+            [1, NotFound],  # should not be able to delete other user entries
+            [7, NotFound],  # should not be able to delete nonexistent entries
+        ],
     )
     def test_delete_entry_invalid(self, tag_handler, entry_id, exception):
         with pytest.raises(exception):
@@ -521,7 +646,6 @@ class TestCreditTagHandler(TestHandler):
 
 
 class TestSaveFormFunctions:
-
     @patch("monopyly.credit.transactions.CreditTransactionHandler")
     @patch("monopyly.credit.forms.CreditTransactionForm")
     def test_save_new_transaction(self, mock_form, mock_handler):
@@ -553,4 +677,3 @@ class TestSaveFormFunctions:
             **mock_transaction_data,
         )
         assert transaction == mock_method.return_value
-
