@@ -7,12 +7,13 @@ from monopyly.database.utils import validate_sort_order
 
 
 @pytest.mark.parametrize(
-    'sort_order, expectation',
-    [['ASC', does_not_raise()],
-     ['DESC', does_not_raise()],
-     ['test', pytest.raises(ValueError)]]
+    "sort_order, expectation",
+    [
+        ["ASC", does_not_raise()],
+        ["DESC", does_not_raise()],
+        ["test", pytest.raises(ValueError)],
+    ],
 )
 def test_validate_sort_order(sort_order, expectation):
     with expectation:
         validate_sort_order(sort_order)
-
