@@ -2,12 +2,10 @@
 from unittest.mock import patch
 
 from monopyly import create_app
+
 # Rename config to avoid Pytest attempting to collect `TestingConfig`
-from monopyly.config import (
-    DevelopmentConfig,
-    ProductionConfig,
-    TestingConfig as _TestingConfig
-)
+from monopyly.config import DevelopmentConfig, ProductionConfig
+from monopyly.config import TestingConfig as _TestingConfig
 
 
 @patch("monopyly.Flask.debug", new=True)
@@ -26,4 +24,3 @@ def test_test_config():
     app = create_app(_TestingConfig)
     assert app.testing
     assert app.config["SECRET_KEY"] == "testing key"
-
